/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWMEDDATATOOLS_NAMESPACE_HPP__
#define __FWMEDDATATOOLS_NAMESPACE_HPP__

/**
 * @brief Contains utilities dedicated to fwMedData.
 */
namespace fwMedDataTools
{
} // namespace fwMedDataTools

#endif //__FWMEDDATATOOLS_NAMESPACE_HPP__
